@@ -3,7 +3,7 @@ package Getopt::Lazy;
 require 5.006;
 
 use version; 
-our $VERSION = qv('0.0.6');
+our $VERSION = qv('0.0.7');
 
 use strict;
 use warnings;
@@ -23,17 +23,17 @@ Getopt::Lazy - Yet another lazy, minimal way of using Getopt::Long
 	-usage => '%c %o file1 [file2 ..]',
 	;
 
-    getopt;
-    print usage and exit 1 unless @ARGV;
+    GetOptions;
+    show_help and exit 1 unless @ARGV;
 
 =head1 DESCRIPTION
 
-Getting tired of the digging the same tedious "getopt" things for every script
-that you write?  This module works for you!
+Got tired of the same tedious "getopt" things in every script
+you wrote?  This module works for you!
 
 =head2 Without Getopt::Lazy
 
-Normally we started a script this way:
+Normally your script would go like this:
 
     use File::Basename;
     use Getopt::Long;
@@ -69,7 +69,7 @@ Normally we started a script this way:
 
 =head2 With Getopt::Lazy
 
-...or, being a little bit "lazier" than usual:
+The same thing using Getopt::Lazy:
 
     use Getopt::Lazy
 	'boolean|b' => 'Turn on the function A',
@@ -79,12 +79,12 @@ Normally we started a script this way:
 	-usage => '%c %o file1 [more-file]',
 	;
 
-    getopt;
-    print usage and exit 1 unless @ARGV;
+    GetOptions;
+    show_help and exit 1 unless @ARGV;
 
 =head2 What We've Got?
 
-The usage() will display the following help screen for you:
+show_help() simply prints out this help screen:
 
     $ lazy
     lazy - Yet another tool for whatever you like
@@ -97,10 +97,8 @@ The usage() will display the following help screen for you:
 
 =head2 Detail Usage
 
-Basically the Getopt::Lazy does two things for you: 1) spawning a variable for
-every given option, and 2) generating GNU-style help message.  (Guess I was too
-lazy to put this down in details.  See for yourself!) If you have other even
-lazier ways of doing the same thing, be sure to let me know!
+Getopt::Lazy does two things for you: 1) spawning a variable for
+every given option, and 2) generating GNU-style help messages.  
 
 =head1 INTERFACE 
 
@@ -109,7 +107,7 @@ lazier ways of doing the same thing, be sure to let me know!
 use Carp;
 
 our @ISA = qw/Exporter/;
-our @EXPORT = qw/GetOptions/;
+our @EXPORT = qw/GetOptions show_help/;
 
 our %opt = ();
 our %usage = ();
@@ -230,8 +228,6 @@ None reported (so far so good.)
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
 Please report any bugs or feature requests to
 C<bug-getopt-lazy@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
@@ -242,7 +238,7 @@ Ruey-Cheng Chen  C<< <rueycheng@gmail.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007, Ruey-Cheng Chen C<< <rueycheng@gmail.com> >>. All rights reserved.
+Copyright (c) 2007, 2015 Ruey-Cheng Chen C<< <rueycheng@gmail.com> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
